power.tpm: Statistical power of truncated product method test under Gaussian mixture model.
Description
Statistical power of truncated product method test under Gaussian mixture model.
Usage
power.tpm(alpha, n, tau1, eps = 0, mu = 0)
Value
Power of the truncated product method test.
Arguments
alpha
- type-I error rate.
n
- dimension parameter, i.e. the number of input p-values.
tau1
- truncation parameter. 0 < tau1 <= 1. tau1 > 0.
eps
- mixing parameter of the Gaussian mixture.
mu
- mean of non standard Gaussian model.
Details
We consider the following hypothesis test,
$$H_0: X_i\sim F_0, H_a: X_i\sim (1-\epsilon)F_0+\epsilon F_1$$
, where \(\epsilon\) is the mixing parameter,
\(F_0\) is the standard normal CDF and \(F = F_1\) is the CDF of normal distribution with \(\mu\) defined by mu and \(\sigma = 1\).
References
1. Hong Zhang and Zheyang Wu. "TFisher Tests: Optimal and Adaptive Thresholding for Combining p-Values", submitted.